@@ -36,26 +36,21 @@ class GsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSession", params)
+            headers = request.headers
+            body = self.call("CreateSession", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateSessionResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateSessionResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeInstancesCount(self, request):
-        """获取实例总数和运行数
+        """获取并发总数和运行数
 
         :param request: Request instance for DescribeInstancesCount.
         :type request: :class:`tencentcloud.gs.v20191118.models.DescribeInstancesCountRequest`
@@ -64,22 +59,17 @@ class GsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstancesCount", params)
+            headers = request.headers
+            body = self.call("DescribeInstancesCount", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeInstancesCountResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeInstancesCountResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SaveGameArchive(self, request):
@@ -92,22 +82,63 @@ class GsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SaveGameArchive", params)
+            headers = request.headers
+            body = self.call("SaveGameArchive", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.SaveGameArchiveResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.SaveGameArchiveResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StartPublishStream(self, request):
+        """开始云端推流
+
+        :param request: Request instance for StartPublishStream.
+        :type request: :class:`tencentcloud.gs.v20191118.models.StartPublishStreamRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.StartPublishStreamResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartPublishStream", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartPublishStreamResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StartPublishStreamToCSS(self, request):
+        """开始云端推流
+
+        :param request: Request instance for StartPublishStreamToCSS.
+        :type request: :class:`tencentcloud.gs.v20191118.models.StartPublishStreamToCSSRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.StartPublishStreamToCSSResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartPublishStreamToCSS", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartPublishStreamToCSSResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopGame(self, request):
@@ -120,22 +151,40 @@ class GsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopGame", params)
+            headers = request.headers
+            body = self.call("StopGame", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.StopGameResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.StopGameResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StopPublishStream(self, request):
+        """停止云端推流
+
+        :param request: Request instance for StopPublishStream.
+        :type request: :class:`tencentcloud.gs.v20191118.models.StopPublishStreamRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.StopPublishStreamResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopPublishStream", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopPublishStreamResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SwitchGameArchive(self, request):
@@ -148,22 +197,17 @@ class GsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SwitchGameArchive", params)
+            headers = request.headers
+            body = self.call("SwitchGameArchive", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.SwitchGameArchiveResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.SwitchGameArchiveResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def TrylockWorker(self, request):
@@ -176,19 +220,14 @@ class GsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TrylockWorker", params)
+            headers = request.headers
+            body = self.call("TrylockWorker", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.TrylockWorkerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.TrylockWorkerResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
